@@ -8,7 +8,9 @@ use {
     solana_runtime::bank::{
         Bank, InnerInstructionsList, NonceRollbackInfo, TransactionLogMessages,
     },
-    solana_transaction_status::{InnerInstructions, Reward, TransactionStatusMeta},
+    solana_transaction_status::{
+        extract_and_fmt_memos, InnerInstructions, Reward, TransactionStatusMeta,
+    },
     std::{
         sync::{
             atomic::{AtomicBool, AtomicU64, Ordering},
@@ -110,8 +112,9 @@ impl TransactionStatusService {
                             })
                             .expect("FeeCalculator must exist");
                         let fee = fee_calculator.calculate_fee(transaction.message());
-                        let (writable_keys, readonly_keys) =
-                            transaction.message.get_account_keys_by_lock_type();
+                        let (writable_keys, readonly_keys) = transaction
+                            .message
+                            .get_account_keys_by_lock_type(bank.demote_program_write_locks());
 
                         let inner_instructions = inner_instructions.map(|inner_instructions| {
                             inner_instructions
@@ -141,6 +144,12 @@ impl TransactionStatusService {
                                 .collect(),
                         );
 
+                        if let Some(memos) = extract_and_fmt_memos(transaction.message()) {
+                            blockstore
+                                .write_transaction_memos(&transaction.signatures[0], memos)
+                                .expect("Expect database write to succeed: TransactionMemos");
+                        }
+
                         blockstore
                             .write_transaction_status(
                                 slot,
@@ -159,7 +168,7 @@ impl TransactionStatusService {
                                     rewards,
                                 },
                             )
-                            .expect("Expect database write to succeed");
+                            .expect("Expect database write to succeed: TransactionStatus");
                     }
                 }
             }
